package com.siwei.rsmonitoring.service;

import java.util.List;

import com.siwei.rsmonitoring.domain.TDkAuditflowType;

/**
 * 地块的审核流程类型Service接口
 *
 * @author siwei
 * @date 2025-01-20
 */
public interface ITDkAuditflowTypeService {
    /**
     * 查询地块的审核流程类型
     *
     * @param id 地块的审核流程类型主键
     * @return 地块的审核流程类型
     */
    public TDkAuditflowType selectTDkAuditflowTypeById(String id);

    /**
     * 查询地块的审核流程类型列表
     *
     * @param tDkAuditflowType 地块的审核流程类型
     * @return 地块的审核流程类型集合
     */
    public List<TDkAuditflowType> selectTDkAuditflowTypeList(TDkAuditflowType tDkAuditflowType);

    /**
     * 新增地块的审核流程类型
     *
     * @param tDkAuditflowType 地块的审核流程类型
     * @return 结果
     */
    public int insertTDkAuditflowType(TDkAuditflowType tDkAuditflowType);


    /**
     * 修改地块的审核流程类型
     *
     * @param tDkAuditflowType 地块的审核流程类型
     * @return 结果
     */
    public int updateTDkAuditflowType(TDkAuditflowType tDkAuditflowType);

    /**
     * 批量删除地块的审核流程类型
     *
     * @param ids 需要删除的地块的审核流程类型主键集合
     * @return 结果
     */
    public int deleteTDkAuditflowTypeByIds(String[] ids);

    /**
     * 删除地块的审核流程类型信息
     *
     * @param id 地块的审核流程类型主键
     * @return 结果
     */
    public int deleteTDkAuditflowTypeById(String id);

    /**
     * 緩存地块的審核流程類型
     */
    public void cacheTDkAuditflowType();

    /**
     * 查询默认地块的審核流程
     */
    public TDkAuditflowType selectTDkAuditflowTypeDefault();

    public List<TDkAuditflowType> selectTDkAuditflowTypeTree();
}
